dollars_raised: dollars_raised

Description Usage Arguments Examples

View source: R/dollars_raised.R

Description

The function outputs the total dollars raised and number of gifts secured by a unit in a given timeframe. The data is pulled from proposals with an assignment to the identified unit.

Usage

1
dollars_raised(unit, from, to)

Arguments

unit

Unit code

from

Start date, in yyyymmdd format

to

End date, in yyyymmdd format

Examples

1
dollars_raised(unit = 'EN', from = 20140101, to = 20180630)

cwolfsonseeley/campaignreports documentation built on May 18, 2019, 3:42 p.m.