Description Usage Arguments Examples
View source: R/dollars_raised.R
The function outputs the total dollars raised and number of gifts secured by a unit in a given timeframe. The data is pulled from proposals with an assignment to the identified unit.
1 | dollars_raised(unit, from, to)
|
unit |
Unit code |
from |
Start date, in yyyymmdd format |
to |
End date, in yyyymmdd format |
1 | dollars_raised(unit = 'EN', from = 20140101, to = 20180630)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.